==> d3-geo-projection-1.2.1.jar: META-INF/resources/webjars/d3-geo-projection/1.2.1/index.js <==
export {default as geoAiry, airyRaw as geoAiryRaw} from "./src/airy";
export {default as geoAitoff, aitoffRaw as geoAitoffRaw} from "./src/aitoff";
export {default as geoArmadillo, armadilloRaw as geoArmadilloRaw} from "./src/armadillo";
export {default as geoAugust, augustRaw as geoAugustRaw} from "./src/august";
export {default as geoBaker, bakerRaw as geoBakerRaw} from "./src/baker";
export {default as geoBerghaus, berghausRaw as geoBerghausRaw} from "./src/berghaus";
export {default as geoBoggs, boggsRaw as geoBoggsRaw} from "./src/boggs";
export {default as geoBonne, bonneRaw as geoBonneRaw} from "./src/bonne";
export {default as geoBottomley, bottomleyRaw as geoBottomleyRaw} from "./src/bottomley";
export {default as geoBromley, bromleyRaw as geoBromleyRaw} from "./src/bromley";
export {default as geoChamberlin, chamberlinRaw as geoChamberlinRaw, chamberlinAfrica as geoChamberlinAfrica} from "./src/chamberlin";
export {default as geoCollignon, collignonRaw as geoCollignonRaw} from "./src/collignon";
export {default as geoCraig, craigRaw as geoCraigRaw} from "./src/craig";
export {default as geoCraster, crasterRaw as geoCrasterRaw} from "./src/craster";
export {default as geoCylindricalEqualArea, cylindricalEqualAreaRaw as geoCylindricalEqualAreaRaw} from "./src/cylindricalEqualArea";
export {default as geoCylindricalStereographic, cylindricalStereographicRaw as geoCylindricalStereographicRaw} from "./src/cylindricalStereographic";
export {default as geoEckert1, eckert1Raw as geoEckert1Raw} from "./src/eckert1.js";
export {default as geoEckert2, eckert2Raw as geoEckert2Raw} from "./src/eckert2.js";
export {default as geoEckert3, eckert3Raw as geoEckert3Raw} from "./src/eckert3.js";
export {default as geoEckert4, eckert4Raw as geoEckert4Raw} from "./src/eckert4.js";
export {default as geoEckert5, eckert5Raw as geoEckert5Raw} from "./src/eckert5.js";
export {default as geoEckert6, eckert6Raw as geoEckert6Raw} from "./src/eckert6.js";
export {default as geoEisenlohr, eisenlohrRaw as geoEisenlohrRaw} from "./src/eisenlohr.js";
export {default as geoFahey, faheyRaw as geoFaheyRaw} from "./src/fahey.js";
export {default as geoFoucaut, foucautRaw as geoFoucautRaw} from "./src/foucaut.js";
export {default as geoGilbert} from "./src/gilbert.js";
export {default as geoGingery, gingeryRaw as geoGingeryRaw} from "./src/gingery.js";
export {default as geoGinzburg4, ginzburg4Raw as geoGinzburg4Raw} from "./src/ginzburg4.js";
export {default as geoGinzburg5, ginzburg5Raw as geoGinzburg5Raw} from "./src/ginzburg5.js";
export {default as geoGinzburg6, ginzburg6Raw as geoGinzburg6Raw} from "./src/ginzburg6.js";
export {default as geoGinzburg8, ginzburg8Raw as geoGinzburg8Raw} from "./src/ginzburg8.js";
export {default as geoGinzburg9, ginzburg9Raw as geoGinzburg9Raw} from "./src/ginzburg9.js";
export {default as geoGringorten, gringortenRaw as geoGringortenRaw} from "./src/gringorten.js";
export {default as geoGuyou, guyouRaw as geoGuyouRaw} from "./src/guyou.js";
export {default as geoHammer, hammerRaw as geoHammerRaw} from "./src/hammer.js";
export {default as geoHammerRetroazimuthal, hammerRetroazimuthalRaw as geoHammerRetroazimuthalRaw} from "./src/hammerRetroazimuthal.js";
export {default as geoHealpix, healpixRaw as geoHealpixRaw} from "./src/healpix.js";
export {default as geoHill, hillRaw as geoHillRaw} from "./src/hill.js";
export {default as geoHomolosine, homolosineRaw as geoHomolosineRaw} from "./src/homolosine.js";
export {default as geoInterrupt} from "./src/interrupted/index";
export {default as geoInterruptedBoggs} from "./src/interrupted/boggs";
export {default as geoInterruptedHomolosine} from "./src/interrupted/homolosine";
export {default as geoInterruptedMollweide} from "./src/interrupted/mollweide";
export {default as geoInterruptedMollweideHemispheres} from "./src/interrupted/mollweideHemispheres";
export {default as geoInterruptedSinuMollweide} from "./src/interrupted/sinuMollweide";
export {default as geoInterruptedSinusoidal} from "./src/interrupted/sinusoidal";
export {default as geoKavrayskiy7, kavrayskiy7Raw as geoKavrayskiy7Raw} from "./src/kavrayskiy7.js";
export {default as geoLagrange, lagrangeRaw as geoLagrangeRaw} from "./src/lagrange.js";
export {default as geoLarrivee, larriveeRaw as geoLarriveeRaw} from "./src/larrivee";
export {default as geoLaskowski, laskowskiRaw as geoLaskowskiRaw} from "./src/laskowski";
export {default as geoLittrow, littrowRaw as geoLittrowRaw} from "./src/littrow.js";
export {default as geoLoximuthal, loximuthalRaw as geoLoximuthalRaw} from "./src/loximuthal.js";
export {default as geoMiller, millerRaw as geoMillerRaw} from "./src/miller";
export {default as geoModifiedStereographic, modifiedStereographicRaw as geoModifiedStereographicRaw, modifiedStereographicAlaska as geoModifiedStereographicAlaska, modifiedStereographicGs48 as geoModifiedStereographicGs48, modifiedStereographicGs50 as geoModifiedStereographicGs50, modifiedStereographicMiller as geoModifiedStereographicMiller, modifiedStereographicLee as geoModifiedStereographicLee} from "./src/modifiedStereographic";
export {default as geoMollweide, mollweideRaw as geoMollweideRaw} from "./src/mollweide";
export {default as geoMtFlatPolarParabolic, mtFlatPolarParabolicRaw as geoMtFlatPolarParabolicRaw} from "./src/mtFlatPolarParabolic";
export {default as geoMtFlatPolarQuartic, mtFlatPolarQuarticRaw as geoMtFlatPolarQuarticRaw} from "./src/mtFlatPolarQuartic";
export {default as geoMtFlatPolarSinusoidal, mtFlatPolarSinusoidalRaw as geoMtFlatPolarSinusoidalRaw} from "./src/mtFlatPolarSinusoidal";
export {default as geoNaturalEarth, naturalEarthRaw as geoNaturalEarthRaw} from "./src/naturalEarth";
export {default as geoNellHammer, nellHammerRaw as geoNellHammerRaw} from "./src/nellHammer";
export {default as geoPatterson, pattersonRaw as geoPattersonRaw} from "./src/patterson";
export {default as geoPolyconic, polyconicRaw as geoPolyconicRaw} from "./src/polyconic";
export {default as geoPolyhedral} from "./src/polyhedral/index.js";
export {default as geoPolyhedralButterfly} from "./src/polyhedral/butterfly.js";
export {default as geoPolyhedralCollignon} from "./src/polyhedral/collignon.js";
export {default as geoPolyhedralWaterman} from "./src/polyhedral/waterman.js";
export {default as geoProject} from "./src/project/index";
export {default as geoGringortenQuincuncial} from "./src/quincuncial/gringorten.js";
export {default as geoPeirceQuincuncial} from "./src/quincuncial/peirce.js";
export {default as geoPierceQuincuncial} from "./src/quincuncial/peirce.js"; // DEPRECATED misspelling
export {default as geoQuantize} from "./src/quantize";
export {default as geoQuincuncial} from "./src/quincuncial/index.js";
export {default as geoRectangularPolyconic, rectangularPolyconicRaw as geoRectangularPolyconicRaw} from "./src/rectangularPolyconic";
export {default as geoRobinson, robinsonRaw as geoRobinsonRaw} from "./src/robinson";
export {default as geoSatellite, satelliteRaw as geoSatelliteRaw} from "./src/satellite";
export {default as geoSinuMollweide, sinuMollweideRaw as geoSinuMollweideRaw} from "./src/sinuMollweide";
export {default as geoSinusoidal, sinusoidalRaw as geoSinusoidalRaw} from "./src/sinusoidal";
export {default as geoStitch} from "./src/stitch";
export {default as geoTimes, timesRaw as geoTimesRaw} from "./src/times";
export {default as geoTwoPointAzimuthal, twoPointAzimuthalRaw as geoTwoPointAzimuthalRaw, twoPointAzimuthalUsa as geoTwoPointAzimuthalUsa} from "./src/twoPointAzimuthal";
export {default as geoTwoPointEquidistant, twoPointEquidistantRaw as geoTwoPointEquidistantRaw, twoPointEquidistantUsa as geoTwoPointEquidistantUsa} from "./src/twoPointEquidistant";
export {default as geoVanDerGrinten, vanDerGrintenRaw as geoVanDerGrintenRaw} from "./src/vanDerGrinten";
export {default as geoVanDerGrinten2, vanDerGrinten2Raw as geoVanDerGrinten2Raw} from "./src/vanDerGrinten2";
export {default as geoVanDerGrinten3, vanDerGrinten3Raw as geoVanDerGrinten3Raw} from "./src/vanDerGrinten3";
export {default as geoVanDerGrinten4, vanDerGrinten4Raw as geoVanDerGrinten4Raw} from "./src/vanDerGrinten4";
export {default as geoWagner4, wagner4Raw as geoWagner4Raw} from "./src/wagner4.js";
export {default as geoWagner6, wagner6Raw as geoWagner6Raw} from "./src/wagner6.js";
export {default as geoWagner7, wagner7Raw as geoWagner7Raw} from "./src/wagner7.js";
export {default as geoWiechel, wiechelRaw as geoWiechelRaw} from "./src/wiechel.js";
export {default as geoWinkel3, winkel3Raw as geoWinkel3Raw} from "./src/winkel3";

==> d3-geo-projection-2.4.0.jar: META-INF/resources/webjars/d3-geo-projection/2.4.0/index.js <==
export {default as geoAiry, airyRaw as geoAiryRaw} from "./src/airy";
export {default as geoAitoff, aitoffRaw as geoAitoffRaw} from "./src/aitoff";
export {default as geoArmadillo, armadilloRaw as geoArmadilloRaw} from "./src/armadillo";
export {default as geoAugust, augustRaw as geoAugustRaw} from "./src/august";
export {default as geoBaker, bakerRaw as geoBakerRaw} from "./src/baker";
export {default as geoBerghaus, berghausRaw as geoBerghausRaw} from "./src/berghaus";
export {default as geoBertin1953, bertin1953Raw as geoBertin1953Raw} from "./src/bertin";
export {default as geoBoggs, boggsRaw as geoBoggsRaw} from "./src/boggs";
export {default as geoBonne, bonneRaw as geoBonneRaw} from "./src/bonne";
export {default as geoBottomley, bottomleyRaw as geoBottomleyRaw} from "./src/bottomley";
export {default as geoBromley, bromleyRaw as geoBromleyRaw} from "./src/bromley";
export {default as geoChamberlin, chamberlinRaw as geoChamberlinRaw, chamberlinAfrica as geoChamberlinAfrica} from "./src/chamberlin";
export {default as geoCollignon, collignonRaw as geoCollignonRaw} from "./src/collignon";
export {default as geoCraig, craigRaw as geoCraigRaw} from "./src/craig";
export {default as geoCraster, crasterRaw as geoCrasterRaw} from "./src/craster";
export {default as geoCylindricalEqualArea, cylindricalEqualAreaRaw as geoCylindricalEqualAreaRaw} from "./src/cylindricalEqualArea";
export {default as geoCylindricalStereographic, cylindricalStereographicRaw as geoCylindricalStereographicRaw} from "./src/cylindricalStereographic";
export {default as geoEckert1, eckert1Raw as geoEckert1Raw} from "./src/eckert1.js";
export {default as geoEckert2, eckert2Raw as geoEckert2Raw} from "./src/eckert2.js";
export {default as geoEckert3, eckert3Raw as geoEckert3Raw} from "./src/eckert3.js";
export {default as geoEckert4, eckert4Raw as geoEckert4Raw} from "./src/eckert4.js";
export {default as geoEckert5, eckert5Raw as geoEckert5Raw} from "./src/eckert5.js";
export {default as geoEckert6, eckert6Raw as geoEckert6Raw} from "./src/eckert6.js";
export {default as geoEisenlohr, eisenlohrRaw as geoEisenlohrRaw} from "./src/eisenlohr.js";
export {default as geoFahey, faheyRaw as geoFaheyRaw} from "./src/fahey.js";
export {default as geoFoucaut, foucautRaw as geoFoucautRaw} from "./src/foucaut.js";
export {default as geoGilbert} from "./src/gilbert.js";
export {default as geoGingery, gingeryRaw as geoGingeryRaw} from "./src/gingery.js";
export {default as geoGinzburg4, ginzburg4Raw as geoGinzburg4Raw} from "./src/ginzburg4.js";
export {default as geoGinzburg5, ginzburg5Raw as geoGinzburg5Raw} from "./src/ginzburg5.js";
export {default as geoGinzburg6, ginzburg6Raw as geoGinzburg6Raw} from "./src/ginzburg6.js";
export {default as geoGinzburg8, ginzburg8Raw as geoGinzburg8Raw} from "./src/ginzburg8.js";
export {default as geoGinzburg9, ginzburg9Raw as geoGinzburg9Raw} from "./src/ginzburg9.js";
export {default as geoGringorten, gringortenRaw as geoGringortenRaw} from "./src/gringorten.js";
export {default as geoGuyou, guyouRaw as geoGuyouRaw} from "./src/guyou.js";
export {default as geoHammer, hammerRaw as geoHammerRaw} from "./src/hammer.js";
export {default as geoHammerRetroazimuthal, hammerRetroazimuthalRaw as geoHammerRetroazimuthalRaw} from "./src/hammerRetroazimuthal.js";
export {default as geoHealpix, healpixRaw as geoHealpixRaw} from "./src/healpix.js";
export {default as geoHill, hillRaw as geoHillRaw} from "./src/hill.js";
export {default as geoHomolosine, homolosineRaw as geoHomolosineRaw} from "./src/homolosine.js";
export {default as geoHyperelliptical, hyperellipticalRaw as geoHyperellipticalRaw} from "./src/hyperelliptical";
export {default as geoInterrupt} from "./src/interrupted/index";
export {default as geoInterruptedBoggs} from "./src/interrupted/boggs";
export {default as geoInterruptedHomolosine} from "./src/interrupted/homolosine";
export {default as geoInterruptedMollweide} from "./src/interrupted/mollweide";
export {default as geoInterruptedMollweideHemispheres} from "./src/interrupted/mollweideHemispheres";
export {default as geoInterruptedSinuMollweide} from "./src/interrupted/sinuMollweide";
export {default as geoInterruptedSinusoidal} from "./src/interrupted/sinusoidal";
export {default as geoKavrayskiy7, kavrayskiy7Raw as geoKavrayskiy7Raw} from "./src/kavrayskiy7.js";
export {default as geoLagrange, lagrangeRaw as geoLagrangeRaw} from "./src/lagrange.js";
export {default as geoLarrivee, larriveeRaw as geoLarriveeRaw} from "./src/larrivee";
export {default as geoLaskowski, laskowskiRaw as geoLaskowskiRaw} from "./src/laskowski";
export {default as geoLittrow, littrowRaw as geoLittrowRaw} from "./src/littrow.js";
export {default as geoLoximuthal, loximuthalRaw as geoLoximuthalRaw} from "./src/loximuthal.js";
export {default as geoMiller, millerRaw as geoMillerRaw} from "./src/miller";
export {default as geoModifiedStereographic, modifiedStereographicRaw as geoModifiedStereographicRaw, modifiedStereographicAlaska as geoModifiedStereographicAlaska, modifiedStereographicGs48 as geoModifiedStereographicGs48, modifiedStereographicGs50 as geoModifiedStereographicGs50, modifiedStereographicMiller as geoModifiedStereographicMiller, modifiedStereographicLee as geoModifiedStereographicLee} from "./src/modifiedStereographic";
export {default as geoMollweide, mollweideRaw as geoMollweideRaw} from "./src/mollweide";
export {default as geoMtFlatPolarParabolic, mtFlatPolarParabolicRaw as geoMtFlatPolarParabolicRaw} from "./src/mtFlatPolarParabolic";
export {default as geoMtFlatPolarQuartic, mtFlatPolarQuarticRaw as geoMtFlatPolarQuarticRaw} from "./src/mtFlatPolarQuartic";
export {default as geoMtFlatPolarSinusoidal, mtFlatPolarSinusoidalRaw as geoMtFlatPolarSinusoidalRaw} from "./src/mtFlatPolarSinusoidal";
export {geoNaturalEarth1 as geoNaturalEarth, geoNaturalEarth1Raw as geoNaturalEarthRaw} from "d3-geo"; // DEPRECATED moved to d3-geo
export {default as geoNaturalEarth2, naturalEarth2Raw as geoNaturalEarth2Raw} from "./src/naturalEarth2";
export {default as geoNellHammer, nellHammerRaw as geoNellHammerRaw} from "./src/nellHammer";
export {default as geoPatterson, pattersonRaw as geoPattersonRaw} from "./src/patterson";
export {default as geoPolyconic, polyconicRaw as geoPolyconicRaw} from "./src/polyconic";
export {default as geoPolyhedral} from "./src/polyhedral/index.js";
export {default as geoPolyhedralButterfly} from "./src/polyhedral/butterfly.js";
export {default as geoPolyhedralCollignon} from "./src/polyhedral/collignon.js";
export {default as geoPolyhedralWaterman} from "./src/polyhedral/waterman.js";
export {default as geoProject} from "./src/project/index";
export {default as geoGringortenQuincuncial} from "./src/quincuncial/gringorten.js";
export {default as geoPeirceQuincuncial} from "./src/quincuncial/peirce.js";
export {default as geoPierceQuincuncial} from "./src/quincuncial/peirce.js"; // DEPRECATED misspelling
export {default as geoQuantize} from "./src/quantize";
export {default as geoQuincuncial} from "./src/quincuncial/index.js";
export {default as geoRectangularPolyconic, rectangularPolyconicRaw as geoRectangularPolyconicRaw} from "./src/rectangularPolyconic";
export {default as geoRobinson, robinsonRaw as geoRobinsonRaw} from "./src/robinson";
export {default as geoSatellite, satelliteRaw as geoSatelliteRaw} from "./src/satellite";
export {default as geoSinuMollweide, sinuMollweideRaw as geoSinuMollweideRaw} from "./src/sinuMollweide";
export {default as geoSinusoidal, sinusoidalRaw as geoSinusoidalRaw} from "./src/sinusoidal";
export {default as geoStitch} from "./src/stitch";
export {default as geoTimes, timesRaw as geoTimesRaw} from "./src/times";
export {default as geoTwoPointAzimuthal, twoPointAzimuthalRaw as geoTwoPointAzimuthalRaw, twoPointAzimuthalUsa as geoTwoPointAzimuthalUsa} from "./src/twoPointAzimuthal";
export {default as geoTwoPointEquidistant, twoPointEquidistantRaw as geoTwoPointEquidistantRaw, twoPointEquidistantUsa as geoTwoPointEquidistantUsa} from "./src/twoPointEquidistant";
export {default as geoVanDerGrinten, vanDerGrintenRaw as geoVanDerGrintenRaw} from "./src/vanDerGrinten";
export {default as geoVanDerGrinten2, vanDerGrinten2Raw as geoVanDerGrinten2Raw} from "./src/vanDerGrinten2";
export {default as geoVanDerGrinten3, vanDerGrinten3Raw as geoVanDerGrinten3Raw} from "./src/vanDerGrinten3";
export {default as geoVanDerGrinten4, vanDerGrinten4Raw as geoVanDerGrinten4Raw} from "./src/vanDerGrinten4";
export {default as geoWagner4, wagner4Raw as geoWagner4Raw} from "./src/wagner4.js";
export {default as geoWagner6, wagner6Raw as geoWagner6Raw} from "./src/wagner6.js";
export {default as geoWagner7, wagner7Raw as geoWagner7Raw} from "./src/wagner7.js";
export {default as geoWiechel, wiechelRaw as geoWiechelRaw} from "./src/wiechel.js";
export {default as geoWinkel3, winkel3Raw as geoWinkel3Raw} from "./src/winkel3";
